@@ -15,12 +15,11 @@
 #' which enables control of the numerical integration parameters.
 #'
 #' ### Output times and windows
-#' The minimum and maximum of given time points generally define the simulated
-#' period. Function argument `times` overrides settings of the scenario, i.e.
-#' time points set in `scenario@times`. However, the simulation can be limited to
+#' The minimum and maximum of given time points define the simulated
+#' period. However, the simulation can also be limited to
 #' a subset of time points by enabling a moving exposure window, see [set_window()].
 #'
-#' Results will be returned for each time point. Precision of the numeric solver
+#' Results will be returned for each output time point. Precision of the numeric solver
 #' may be affected by chosen output times in certain cases. Hence, small deviations
 #' in results should be expected if different output times are set. This effect
 #' can be mitigated by either defining are sufficiently small time step for the solver
@@ -72,50 +71,61 @@
 #'
 #' @param x [scenario] to simulate
 # @param times optional `numeric` vector of time points for which results are returned,
-# overrides settings of the scenario
+#   overrides settings of the scenario
 #' @param ... additional parameters passed on to ODE solver
 #'
 #' @return A `data.frame` with the time-series of simulation results
 #' @export
 #' @examples
-#' minnow_sd %>% simulate() # tidy syntax
-#' simulate(minnow_sd) # base R syntax
+#' # base R syntax
+#' simulate(minnow_sd)
+#' # tidy syntax with the same result
+#' minnow_sd %>% simulate()
 #'
-#' # Set new output times
-#' minnow_sd %>% simulate(times=c(0,4))
+#' # Extend the simulated time frame to the interval [0, 10]
+#' minnow_sd %>%
+#'   set_times(seq(0, 10)) %>%
+#'   simulate()
 #'
-#' # Modify simulated time frame
-#' minnow_sd %>% simulate(times=c(0,10))
-#'
-#' # Use an alternative exposure profile than defined in the scenario
-#' minnow_sd %>% set_exposure(data.frame(t=0,c=10), reset_times=FALSE) %>% simulate()
+#' # Use an alternative exposure profile, but keep the original output times
+#' minnow_sd %>%
+#'   set_exposure(data.frame(t=0, c=10), reset_times=FALSE) %>%
+#'   simulate()
 #'
 #' ##
 #' ## Precision of results
 #'
 #' # A large number of output times forces smaller solver time steps
-#' minnow_it %>% simulate(times=seq(0,1,0.001)) %>% tail()
+#' minnow_it %>%
+#'   set_times(seq(0, 10, 0.001)) %>%
+#'   simulate() %>%
+#'   tail()
 #'
-#' # Defining only two output times allows for larger solver time steps
-#' minnow_it %>% simulate(times=c(0,1))
+#' # Defining only two output times allows the ODE solver to make larger steps
+#' # in time during numerical integration. However, results can become
+#' # imprecise.
+#' minnow_long <- minnow_it %>% set_times(c(0, 10))
+#' minnow_long %>% simulate()
 #'
-#' # The difference between results can be reduced by limiting the solver's
-#' # maximum step length
-#' minnow_it %>% simulate(times=c(0,1), hmax=0.001)
+#' # Numerical precision of results can be increased by limiting the solver's
+#' # maximum step length in time using argument `hmax`.
+#' minnow_long %>% simulate(hmax=0.005)
 #'
-#' # The same numerical precision can be achieved by switching to
-#' # the Radau scheme
-#' minnow_it %>% simulate(times=c(0,1), method="radau")
+#' # A similar numerical precision can be achieved by switching to an alternative
+#' # numerical integration scheme, such as the Radau scheme, without limiting
+#' # the step length.
+#' minnow_long %>% simulate(method="radau")
 #'
-#' # A very small step length may reduce the difference even further but may
-#' # also exceed the allowed number of steps per output interval. The following
-#' # simulation will be aborted with a solver error:
+#' # Reducing the step length even further may increase numerical precision, but
+#' # may exceed the solver's allowed number of integration steps per output interval.
+#' # The following simulation will be aborted with a solver error:
 #' try(
-#'   minnow_it %>% simulate(times=c(0,1), hmax=0.0001)
+#'   minnow_long %>% simulate(hmax=0.001)
 #' )
 #'
-#' # However, the solver's max number of allowed steps can be increased:
-#' minnow_it %>% simulate(times=c(0,1), hmax=0.0001, maxsteps=10^5)
+#' # However, the solver's maximum number of allowed steps can be increased,
+#' # if needed, using the argument `maxsteps`:
+#' minnow_long %>% simulate(hmax=0.001, maxsteps=10^5)
 setGeneric("simulate", function(x, ...) standardGeneric("simulate"), signature="x")
 
 #' default for all models using sliding exposure windows
@@ -128,13 +138,20 @@ setMethod("simulate", "EffectScenario", function(x, ...) simulate_scenario(x, ..
 setMethod("simulate", "Transferable", function(x, ...) simulate_transfer(scenario=x, ...))
 
 #' @rdname simulate
-#' @include class-ScenarioSequence.R
+#' @include sequence.R
 setMethod("simulate", "ScenarioSequence", function(x, ...) simulate_seq(seq=x, ...))
 
+#' @rdname simulate
+#' @include batch.R
+setMethod("simulate", "SimulationBatch", function(x, ...) simulate_batch2(batch=x, ...))
+
 
 # Wrapper for solver function to enforce setting of a S3 class for all simulation
 # results.
-simulate_scenario <- function(x, ...) {
+simulate_scenario <- function(x, times, ...) {
+  if(!missing(times))
+    x <- set_times(x, times)
+
   rs <- solver(scenario=x, ...)
   class(rs) <- c("cvasi.simulate", class(rs))
   rs
@@ -158,34 +175,40 @@ simulate_scenario <- function(x, ...) {
 simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
   if(!has_transfer(scenario)) # shortcut if no transfers were defined
     return(simulate_scenario(scenario, times=times, ...))
+  if(!missing(times))
+    scenario <- set_times(scenario, times)
 
-  if(missing(times))
-    times <- scenario@times
-  if(length(times)<2)
-    stop("at least two output times required")
-
+  times <- scenario@times
   t_min <- min(times)
-  if(t_min < 0)
-    stop("output times must not be negative")
   t_max <- max(times)
 
   # find transfer time points that occur during the simulated period
   tr_points <- vector("numeric")
   ends_on_transfer <- FALSE
   if(has_regular_transfer(scenario)) {
-    # sim has to be long enough for transfers to occur
-    if(t_max >= scenario@transfer.interval) {
-      tr_points <- seq(scenario@transfer.interval, t_max, scenario@transfer.interval)
-    }
+    seq_start <- ceiling(t_min / scenario@transfer.interval) * scenario@transfer.interval
+    seq_end <- t_max
+    if(seq_start <= seq_end) # avoid errors in case no transfer occurs
+      tr_points <- seq(seq_start, seq_end, scenario@transfer.interval)
   } else {
     tr_points <- scenario@transfer.times
   }
+  # does simulation period end on a transfer?
   if(length(tr_points) > 0)
-    ends_on_transfer <- tail(tr_points, 1) == t_max
+    ends_on_transfer <- tr_points[length(tr_points)] == t_max
   # limit vector to transfer time points which occur during the simulated period.
   # but exclude the starting time as a potential transfer
   tr_points <- tr_points[tr_points > t_min & tr_points <= t_max]
 
+  # if no transfer occurs during simulated period -> early exit
+  if(length(tr_points) == 0 & !ends_on_transfer)
+    return(simulate_scenario(set_times(scenario, times), ...))
+
+  # add all transfer time points to the output times vector
+  tr_inserted <- setdiff(tr_points, times)
+  if(length(tr_inserted) > 0)
+    times <- sort(c(times, tr_inserted))
+
   # biomass level after each transfer
   if(length(scenario@transfer.biomass) == 1)
     tr_biomass <- rep(scenario@transfer.biomass, times=length(tr_points))
@@ -194,34 +217,26 @@ simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
   else
     stop("length of biomass and transfer times vectors do not match", call.=FALSE)
 
-  # if no transfers occur -> early exit
-  if(length(tr_points) == 0 & !ends_on_transfer)
-    return(simulate_scenario(scenario, times=times, ...))
-
-  # transfer time points must be contained in output time points
-  if(length(setdiff(tr_points, times)) > 0)
-    stop(paste("transfer time points missing in output times:", paste(setdiff(tr_points, times), sep=",")))
-
   df <- data.frame()
   t_start <- t_min
-  #tr_points <- c(tr_points, t_max)
-  #tr_biomass <- c(tr_biomass, NA_real_) # dummy value
+  # add last time point to also simulate the remainder of the scenario, if it exists
+  if(!ends_on_transfer)
+    tr_points <- c(tr_points, t_max)
   # simulate population until next transfer to new medium
-  for(i in seq_along(tr_points)) {
-    t <- tr_points[i]
-    period <- times[times >= t_start & times <= t]
-    # simulate
-    out <- solver(scenario, times=period, ...)
+  for(i in seq_along(tr_points))
+  {
+    tr <- tr_points[i]
+    period <- times[times >= t_start & times <= tr]
+    out <- solver(set_times(scenario, period), ...)
 
-    # append results to output data.frame
-    if(i==1) {
-      df <- rbind(df, out)
-    } else {
-      # append simulation results, but exclude values for the starting time point
-      # where the transfer occurred. the starting time point `t` could be included more
-      # than once in the `times` or `period` vector
-      df <- rbind(df, out[-seq(sum(period == t)),])
+    # select rows/time points:
+    # 1) that do NOT occur directly after a transfer, i.e. the start of a simulation
+    selector <- i == 1 | period != t_start
+    # 2) that were NOT inserted for technical reasons
+    if(length(tr_inserted) > 0) {
+      selector <- selector & !(period %in% tr_inserted)
     }
+    df <- rbind(df, out[selector, ])
 
     # Transfer a fixed number of biomass to a new medium:
     # use last state as starting point
@@ -233,13 +248,7 @@ simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
     # scale other compartments relative to new biomass
     init[scenario@transfer.comp.scaled] <- init[scenario@transfer.comp.scaled] * BM.fac
     scenario <- set_init(scenario, init)
-    t_start <- t
-  }
-  # simulate the remainder of the scenario if any exists
-  if(t_max > max(tr_points)) {
-    period <- times[times >= t_start]
-    out <- solver(scenario, times=period, ...)
-    df <- rbind(df, out[-1,])
+    t_start <- tr
   }
 
   # add metadata at which system state the subsequent simulation should start
@@ -265,6 +274,8 @@ simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
 simulate_seq <- function(seq, times, ...) {
   if(length(seq@scenarios)==0)
     stop("no scenarios in sequence")
+  if(!missing(times))
+    stop("overriding output times not supported for scenario sequences")
 
   df <- data.frame() # result table
   init <- seq@scenarios[[1]]@init
@@ -288,7 +299,7 @@ simulate_seq <- function(seq, times, ...) {
       stop("scenarios are not on a continuous time scale")
     t.start <- tail(sc@times,1)
     # we simulate each scenario as is
-    out <- simulate(sc, times, in_sequence=TRUE, ...)
+    out <- simulate(sc, times=times, in_sequence=TRUE, ...)
     # append results to output data.frame
     if(i==1)
       df <- rbind(df, out)
@@ -309,9 +320,56 @@ simulate_seq <- function(seq, times, ...) {
   df
 }
 
+# Simulate a batch of scenarios
+#
+# A batch consist of a base scenario and number of exposure series that are
+# simulated with said base scenario. This is intended to replicate the setup
+# of ecotox effect studies.
+#
+# This function is not intended to be invoked by the user, but the user is
+# expected to make a call such as `simulate(batch(myscenario, list(1, 2, 3)))`.
+# Parameters that influence the format of the return value are documented
+# by [batch()].
+simulate_batch2 <- function(batch, times, ...) {
+  # some basic checks
+  if(!is.character(batch@id_col))
+    stop("id column is missing")
+  if(batch@format != "long" & batch@format != "wide")
+    stop("invalid format selected")
+  if(!missing(times))
+    batch@scenarios <- lapply(batch@scenarios, set_times, times)
+
+  # TODO parallelization strategy should be controllable by user
+  df <- furrr::future_map2_dfr(
+    batch@scenarios,
+    names(batch@scenarios),
+    function(sc, nm, id_col) {
+      rs <- simulate(sc, ...)
+      rs[[id_col]] <- nm
+      rs
+    },
+    id_col=batch@id_col
+  )
+
+  # if the user specified one or more columns to select, then we will select
+  # a subset from the simulation results, but always time (1st colum), and
+  # the (trial) ids as well
+  if(!is.null(batch@select)) {
+    # magic value 1: we assume that the first column contains time
+    df <- dplyr::select(df, 1, !c(1, batch@id_col) & batch@select, batch@id_col)
+  }
+  # pivot to wide format?
+  if(batch@format == "wide") {
+    df <- tidyr::pivot_wider(df, id_cols=1, names_from=batch@id_col, values_from=!c(1, batch@id_col))
+  }
+
+  df
+}
+
 #' Batch simulation using multiple exposure series
 #'
-#' `r lifecycle::badge("experimental")`
+#' `r lifecycle::badge("deprecated")`
+#'
 #' A convenience function to simulate a single base scenario with one or more
 #' exposure series. This aims at reproducing the setup and results of common
 #' effect studies.
@@ -342,6 +400,7 @@ simulate_seq <- function(seq, times, ...) {
 #' metsulfuron %>%
 #'   simulate_batch(treatments)
 simulate_batch <- function(model_base, treatments, param_sample=deprecated()) {
+  #lifecycle::deprecate_soft("1.4.0", "simulate_batch()", details="Please use `simulate(batch())` instead")
   if(is_present(param_sample)) {
     if(!is.null(param_sample)) {
       lifecycle::deprecate_stop("1.3.0", "simulate_batch(param_sample)")
